@@ -10,7 +10,6 @@
  * Gets some core libraries
  */
 require_once 'libraries/common.inc.php';
-require_once 'libraries/tbl_columns_definition_form.lib.php';
 require_once 'libraries/central_columns.lib.php';
 
 if (isset($_POST['edit_save']) || isset($_POST['add_new_column'])) {
@@ -22,7 +21,7 @@ if (isset($_POST['edit_save']) || isset($_POST['add_new_column'])) {
     if ($col_default == 'NONE' && $_POST['col_default_sel'] != 'USER_DEFINED') {
         $col_default = "";
     }
-    $col_extra = $_POST['col_extra'];
+    $col_extra = isset($_POST['col_extra']) ? $_POST['col_extra'] : '';
     $col_isNull = isset($_POST['col_isNull'])?1:0;
     $col_length = $_POST['col_length'];
     $col_attribute = $_POST['col_attribute'];
@@ -30,13 +29,13 @@ if (isset($_POST['edit_save']) || isset($_POST['add_new_column'])) {
     $collation = $_POST['collation'];
     if (isset($orig_col_name) && $orig_col_name) {
         echo PMA_updateOneColumn(
-            $db, $orig_col_name, $col_name, $col_type,$col_attribute,
+            $db, $orig_col_name, $col_name, $col_type, $col_attribute,
             $col_length, $col_isNull, $collation, $col_extra, $col_default
         );
         exit;
     } else {
         $tmp_msg = PMA_updateOneColumn(
-            $db, "", $col_name, $col_type,$col_attribute,
+            $db, "", $col_name, $col_type, $col_attribute,
             $col_length, $col_isNull, $collation, $col_extra, $col_default
         );
     }
@@ -66,17 +65,34 @@ $cfgCentralColumns = PMA_centralColumnsGetParams();
 $pmadb = $cfgCentralColumns['db'];
 $pmatable = $cfgCentralColumns['table'];
 $max_rows = $GLOBALS['cfg']['MaxRows'];
+
+if (isset($_REQUEST['edit_central_columns_page'])) {
+    $selected_fld = $_REQUEST['selected_fld'];
+    $selected_db = $_REQUEST['db'];
+    $edit_central_column_page = PMA_getHTMLforEditingPage(
+        $selected_fld, $selected_db
+    );
+    $response->addHTML($edit_central_column_page);
+    exit;
+}
+if (isset($_POST['multi_edit_central_column_save'])) {
+    $message = PMA_updateMultipleColumn();
+    if (!is_bool($message)) {
+        $response->isSuccess(false);
+        $response->addJSON('message', $message);
+    }
+}
 if (isset($_POST['delete_save'])) {
     $col_name = array();
-    $col_name[] = $_REQUEST['col_name'];
-    $tmp_msg = PMA_deleteColumnsFromList($col_name, false);
+    parse_str($_POST['col_name'], $col_name);
+    $tmp_msg = PMA_deleteColumnsFromList($col_name['selected_fld'], false);
 }
 if (isset($_REQUEST['total_rows']) && $_REQUEST['total_rows']) {
     $total_rows = $_REQUEST['total_rows'];
 } else {
     $total_rows = PMA_getCentralColumnsCount($db);
 }
-if (isset($_REQUEST['pos'])) {
+if (PMA_isValid($_REQUEST['pos'], 'integer')) {
     $pos = $_REQUEST['pos'];
 } else {
     $pos = 0;
@@ -106,6 +122,7 @@ $deleteRowForm = '<form method="post" id="del_form" action="db_central_columns.p
         . '<input type="hidden" name="delete_save" value="delete"></form>';
 $response->addHTML($deleteRowForm);
 $table_struct = '<div id="tableslistcontainer">'
+        . '<form name="tableslistcontainer">'
         . '<table id="table_columns" class="tablesorter" '
         . 'style="min-width:100%" class="data">';
 $response->addHTML($table_struct);
@@ -115,7 +132,7 @@ $tableheader = PMA_getCentralColumnsTableHeader(
 $response->addHTML($tableheader);
 $result = PMA_getColumnsList($db, $pos, $max_rows);
 $odd_row = true;
-$row_num=0;
+$row_num = 0;
 foreach ($result as $row) {
     $tableHtmlRow = PMA_getHTMLforCentralColumnsTableRow(
         $row, $odd_row, $row_num, $db
@@ -124,11 +141,13 @@ foreach ($result as $row) {
     $odd_row = !$odd_row;
     $row_num++;
 }
-$response->addHTML('</table></div>');
+$response->addHTML('</table>');
+$tablefooter = PMA_getCentralColumnsTableFooter($pmaThemeImage, $text_dir);
+$response->addHTML($tablefooter);
+$response->addHTML('</form></div>');
 $message = PMA_Message::success(
     sprintf(__('Showing rows %1$s - %2$s.'), ($pos + 1), ($pos + count($result)))
 );
 if (isset($tmp_msg) && $tmp_msg !== true) {
     $message = $tmp_msg;
 }
-?>
