@@ -16,6 +16,7 @@ require_once 'libraries/mysql_charsets.inc.php';
 /**
  * Include all other files
  */
+require_once 'libraries/check_user_privileges.lib.php';
 require_once 'libraries/rte/rte_routines.lib.php';
 
 /**
@@ -23,5 +24,3 @@ require_once 'libraries/rte/rte_routines.lib.php';
  */
 $_PMA_RTE = 'RTN';
 require_once 'libraries/rte/rte_main.inc.php';
-
-?>
