@@ -64,11 +64,12 @@ if (isset($_REQUEST['console_bookmark_add'])) {
     }
 }
 
+$format = '';
+
 /**
  * Sets globals from $_POST
  */
 $post_params = array(
-    'bkm_label',
     'charset_of_file',
     'format',
     'import_type',
@@ -76,7 +77,6 @@ $post_params = array(
     'MAX_FILE_SIZE',
     'message_to_show',
     'noplugin',
-    'skip',
     'skip_queries',
     'local_import_file'
 );
@@ -100,9 +100,33 @@ if (!isset($_SESSION['is_multi_query'])) {
     $_SESSION['is_multi_query'] = false;
 }
 
+$ajax_reload = array();
 // Are we just executing plain query or sql file?
 // (eg. non import, but query box/window run)
 if (! empty($sql_query)) {
+
+    // apply values for parameters
+    if (! empty($_REQUEST['parameterized'])
+        && ! empty($_REQUEST['parameters'])
+        && is_array($_REQUEST['parameters'])) {
+        $parameters = $_REQUEST['parameters'];
+        foreach ($parameters as $parameter => $replacement) {
+            $quoted = preg_quote($parameter);
+            // making sure that :param does not apply values to :param1
+            $sql_query = preg_replace(
+                '/' . $quoted . '([^a-zA-Z0-9_])/',
+                PMA_Util::sqlAddSlashes($replacement) . '${1}',
+                $sql_query
+            );
+            // for parameters the appear at the end of the string
+            $sql_query = preg_replace(
+                '/' . $quoted . '$/',
+                PMA_Util::sqlAddSlashes($replacement),
+                $sql_query
+            );
+        }
+    }
+
     // run SQL query
     $import_text = $sql_query;
     $import_type = 'query';
@@ -117,6 +141,7 @@ if (! empty($sql_query)) {
     // refresh navigation and main panels
     if (preg_match('/^(DROP)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i', $sql_query)) {
         $GLOBALS['reload'] = true;
+        $ajax_reload['reload'] = true;
     }
 
     // refresh navigation panel only
@@ -124,7 +149,7 @@ if (! empty($sql_query)) {
         '/^(CREATE|ALTER)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i',
         $sql_query
     )) {
-        $ajax_reload = array('reload' => true);
+        $ajax_reload['reload'] = true;
     }
 
     // do a dynamic reload if table is RENAMED
@@ -134,17 +159,11 @@ if (! empty($sql_query)) {
         $sql_query,
         $rename_table_names
     )) {
-        $ajax_reload = array('reload' => true);
+        $ajax_reload['reload'] = true;
         $ajax_reload['table_name'] = PMA_Util::unQuote($rename_table_names[2]);
     }
 
     $sql_query = '';
-} elseif (! empty($sql_localfile)) {
-    // run SQL file on server
-    $local_import_file = $sql_localfile;
-    $import_type = 'queryfile';
-    $format = 'sql';
-    unset($sql_localfile);
 } elseif (! empty($sql_file)) {
     // run uploaded SQL file
     $import_file = $sql_file;
@@ -161,7 +180,10 @@ if (! empty($sql_query)) {
 // upload limit has been reached, let's assume the second possibility.
 if ($_POST == array() && $_GET == array()) {
     $message = PMA_Message::error(
-        __('You probably tried to upload a file that is too large. Please refer to %sdocumentation%s for a workaround for this limit.')
+        __(
+            'You probably tried to upload a file that is too large. Please refer ' .
+            'to %sdocumentation%s for a workaround for this limit.'
+        )
     );
     $message->addParam('[doc@faq1-16]');
     $message->addParam('[/doc]');
@@ -311,9 +333,7 @@ if (! empty($_REQUEST['id_bookmark'])) {
             isset($_REQUEST['action_bookmark_all'])
         );
         if (! empty($_REQUEST['bookmark_variable'])) {
-            $import_text = preg_replace(
-                '|/\*(.*)\[VARIABLE\](.*)\*/|imsU',
-                '${1}' . PMA_Util::sqlAddSlashes($_REQUEST['bookmark_variable']) . '${2}',
+            $import_text = PMA_Bookmark_applyVariables(
                 $import_text
             );
         }
@@ -324,6 +344,7 @@ if (! empty($_REQUEST['id_bookmark'])) {
             $import_text
         )) {
             $GLOBALS['reload'] = true;
+            $ajax_reload['reload'] = true;
         }
 
         // refresh navigation panel only
@@ -332,9 +353,6 @@ if (! empty($_REQUEST['id_bookmark'])) {
             $import_text
         )
         ) {
-            if (! isset($ajax_reload)) {
-                $ajax_reload = array();
-            }
             $ajax_reload['reload'] = true;
         }
         break;
@@ -434,7 +452,7 @@ if ($import_file != 'none' && ! $error) {
             $tmp_subdir = sys_get_temp_dir();
         }
         $tmp_subdir = rtrim($tmp_subdir, DIRECTORY_SEPARATOR);
-        if (is_writable($tmp_subdir)) {
+        if (@is_writable($tmp_subdir)) {
             $import_file_new = $tmp_subdir . DIRECTORY_SEPARATOR
                 . basename($import_file) . uniqid();
             if (move_uploaded_file($import_file, $import_file_new)) {
@@ -452,7 +470,11 @@ if ($import_file != 'none' && ! $error) {
             // instead.
 
             $message = PMA_Message::error(
-                __('Uploaded file cannot be moved, because the server has open_basedir enabled without access to the %s directory (for temporary files).')
+                __(
+                    'Uploaded file cannot be moved, because the server has ' .
+                    'open_basedir enabled without access to the %s directory ' .
+                    '(for temporary files).'
+                )
             );
             $message->addParam($tmp_subdir);
             PMA_stopImport($message);
@@ -475,7 +497,11 @@ if ($import_file != 'none' && ! $error) {
             $import_handle = @bzopen($import_file, 'r');
         } else {
             $message = PMA_Message::error(
-                __('You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.')
+                __(
+                    'You attempted to load file with unsupported compression ' .
+                    '(%s). Either support for it is not implemented or disabled ' .
+                    'by your configuration.'
+                )
             );
             $message->addParam($compression);
             PMA_stopImport($message);
@@ -486,7 +512,11 @@ if ($import_file != 'none' && ! $error) {
             $import_handle = @gzopen($import_file, 'r');
         } else {
             $message = PMA_Message::error(
-                __('You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.')
+                __(
+                    'You attempted to load file with unsupported compression ' .
+                    '(%s). Either support for it is not implemented or disabled ' .
+                    'by your configuration.'
+                )
             );
             $message->addParam($compression);
             PMA_stopImport($message);
@@ -507,7 +537,11 @@ if ($import_file != 'none' && ! $error) {
             }
         } else {
             $message = PMA_Message::error(
-                __('You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.')
+                __(
+                    'You attempted to load file with unsupported compression ' .
+                    '(%s). Either support for it is not implemented or disabled ' .
+                    'by your configuration.'
+                )
             );
             $message->addParam($compression);
             PMA_stopImport($message);
@@ -518,7 +552,11 @@ if ($import_file != 'none' && ! $error) {
         break;
     default:
         $message = PMA_Message::error(
-            __('You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.')
+            __(
+                'You attempted to load file with unsupported compression (%s). ' .
+                'Either support for it is not implemented or disabled by your ' .
+                'configuration.'
+            )
         );
         $message->addParam($compression);
         PMA_stopImport($message);
@@ -532,7 +570,11 @@ if ($import_file != 'none' && ! $error) {
 } elseif (! $error) {
     if (! isset($import_text) || empty($import_text)) {
         $message = PMA_Message::error(
-            __('No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See [doc@faq1-16]FAQ 1.16[/doc].')
+            __(
+                'No data was received to import. Either no file name was ' .
+                'submitted, or the file size exceeded the maximum size permitted ' .
+                'by your PHP configuration. See [doc@faq1-16]FAQ 1.16[/doc].'
+            )
         );
         PMA_stopImport($message);
     }
@@ -565,9 +607,9 @@ if ($GLOBALS['PMA_recoding_engine'] != PMA_CHARSET_NONE && isset($charset_of_fil
     }
 }
 
-// Something to skip?
-if (! $error && isset($skip)) {
-    $original_skip = $skip;
+// Something to skip? (because timeout has passed)
+if (! $error && isset($_POST['skip'])) {
+    $original_skip = $skip = $_POST['skip'];
     while ($skip > 0) {
         PMA_importGetNextChunk($skip < $read_limit ? $skip : $read_limit);
         // Disable read progressivity, otherwise we eat all memory!
@@ -584,6 +626,7 @@ $sql_data = array('valid_sql' => array(), 'valid_queries' => 0);
 if (! $error) {
     // Check for file existence
     include_once "libraries/plugin_interface.lib.php";
+    /* @var $import_plugin ImportPlugin */
     $import_plugin = PMA_getPlugin(
         "import",
         $format,
@@ -597,7 +640,14 @@ if (! $error) {
         PMA_stopImport($message);
     } else {
         // Do the real import
-        $import_plugin->doImport($sql_data);
+        try {
+            $default_fk_check = PMA_Util::handleDisableFKCheckInit();
+            $import_plugin->doImport($sql_data);
+            PMA_Util::handleDisableFKCheckCleanup($default_fk_check);
+        } catch (Exception $e) {
+            PMA_Util::handleDisableFKCheckCleanup($default_fk_check);
+            throw $e;
+        }
     }
 }
 
@@ -628,7 +678,7 @@ if (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 2) {
 } elseif ($bookmark_created) {
     $special_message = '[br]'  . sprintf(
         __('Bookmark %s has been created.'),
-        htmlspecialchars($bkm_label)
+        htmlspecialchars($_POST['bkm_label'])
     );
 } elseif ($finished && ! $error) {
     if ($import_type == 'query') {
@@ -656,7 +706,9 @@ if (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 2) {
 
 // Did we hit timeout? Tell it user.
 if ($timeout_passed) {
-    $importUrl = $err_url .= '&timeout_passed=1&offset=' . urlencode($GLOBALS['offset']);
+    $importUrl = $err_url .= '&timeout_passed=1&offset=' . urlencode(
+        $GLOBALS['offset']
+    );
     if (isset($local_import_file)) {
         $importUrl .= '&local_import_file=' . urlencode($local_import_file);
     }
@@ -718,19 +770,27 @@ if ($go_sql) {
         include 'libraries/parse_analyze.inc.php';
 
         $html_output .= PMA_executeQueryAndGetQueryResponse(
-            $analyzed_sql_results, false, $db, $table, null,
-            $sql_query, null, $analyzed_sql_results['is_affected'],
-            null, null, null, $goto, $pmaThemeImage,
-            null, null, null, $sql_query, null, null
+            $analyzed_sql_results, // analyzed_sql_results
+            false, // is_gotofile
+            $db, // db
+            $table, // table
+            null, // find_real_end
+            $_REQUEST['sql_query'], // sql_query_for_bookmark
+            null, // extra_data
+            null, // message_to_show
+            null, // message
+            null, // sql_data
+            $goto, // goto
+            $pmaThemeImage, // pmaThemeImage
+            null, // disp_query
+            null, // disp_message
+            null, // query_type
+            $sql_query, // sql_query
+            null, // selectedTables
+            null // complete_query
         );
     }
 
-    if (!isset($ajax_reload)) {
-        $ajax_reload = array();
-    }
-    if (isset($table)) {
-        $ajax_reload['table_name'] = $table;
-    }
     $response = PMA_Response::getInstance();
     $response->addJSON('ajax_reload', $ajax_reload);
     $response->addHTML($html_output);
@@ -767,4 +827,3 @@ if ($go_sql) {
 if (isset($_REQUEST['rollback_query'])) {
     $GLOBALS['dbi']->query('ROLLBACK');
 }
-?>
