@@ -14,8 +14,7 @@ if (! defined('PHPMYADMIN')) {
  *
  * @package PhpMyAdmin-Engines
  */
-class PMA_StorageEngine_merge extends PMA_StorageEngine
+class PMA_StorageEngine_Merge extends PMA_StorageEngine
 {
 }
 
-?>
