@@ -52,7 +52,12 @@ abstract class AbstractImportCsv extends ImportPlugin
         // create common items and add them to the group
         $leaf = new BoolPropertyItem();
         $leaf->setName("replace");
-        $leaf->setText(__('Update data when duplicate keys found on import (add ON DUPLICATE KEY UPDATE)'));
+        $leaf->setText(
+            __(
+                'Update data when duplicate keys found on import (add ON DUPLICATE '
+                . 'KEY UPDATE)'
+            )
+        );
         $generalOptions->addProperty($leaf);
         $leaf = new TextPropertyItem();
         $leaf->setName("terminated");
@@ -87,4 +92,3 @@ abstract class AbstractImportCsv extends ImportPlugin
         return $generalOptions;
     }
 }
-?>
\ No newline at end of file
