@@ -149,7 +149,7 @@ class ImportOds extends ImportPlugin
          * result in increased performance without the need to
          * alter the code in any way. It's basically a freebee.
          */
-        $xml = simplexml_load_string($buffer, "SimpleXMLElement", LIBXML_COMPACT);
+        $xml = @simplexml_load_string($buffer, "SimpleXMLElement", LIBXML_COMPACT);
 
         unset($buffer);
 
@@ -163,6 +163,7 @@ class ImportOds extends ImportPlugin
             );
             $GLOBALS['error'] = true;
         } else {
+            /** @var SimpleXMLElement $root */
             $root = $xml->children('office', true)->{'body'}->{'spreadsheet'};
             if (empty($root)) {
                 $sheets = array();
@@ -187,10 +188,12 @@ class ImportOds extends ImportPlugin
         $rows = array();
 
         /* Iterate over tables */
+        /** @var SimpleXMLElement $sheet */
         foreach ($sheets as $sheet) {
             $col_names_in_first_row = isset($_REQUEST['ods_col_names']);
 
             /* Iterate over rows */
+            /** @var SimpleXMLElement $row */
             foreach ($sheet as $row) {
                 $type = $row->getName();
                 if (strcmp('table-row', $type)) {
@@ -199,6 +202,7 @@ class ImportOds extends ImportPlugin
                 /* Iterate over columns */
                 $cellCount = count($row);
                 $a = 0;
+                /** @var SimpleXMLElement $cell */
                 foreach ($row as $cell) {
                     $a++;
                     $text = $cell->children('text', true);
@@ -330,9 +334,10 @@ class ImportOds extends ImportPlugin
         /**
          * Bring accumulated rows into the corresponding table
          */
-        $num_tbls = count($tables);
-        for ($i = 0; $i < $num_tbls; ++$i) {
-            for ($j = 0; $j < count($rows); ++$j) {
+        $num_tables = count($tables);
+        for ($i = 0; $i < $num_tables; ++$i) {
+            $num_rows = count($rows);
+            for ($j = 0; $j < $num_rows; ++$j) {
                 if (strcmp($tables[$i][TBL_NAME], $rows[$j][TBL_NAME])) {
                     continue;
                 }
