@@ -59,11 +59,15 @@ abstract class TextFileUploadTransformationsPlugin extends IOTransformationsPlug
      * @param array  $options              transformation options
      * @param string $value                Current field value
      * @param string $text_dir             text direction
+     * @param int    $tabindex             tab index
+     * @param int    $tabindex_for_value   offset for the values tabindex
+     * @param int    $idindex              id index
      *
      * @return string the html for input field
      */
     public function getInputHtml(
-        $column, $row_id, $column_name_appendix, $options, $value, $text_dir
+        $column, $row_id, $column_name_appendix, $options, $value, $text_dir,
+        $tabindex, $tabindex_for_value, $idindex
     ) {
         $html = '';
         if (!empty($value)) {
@@ -90,4 +94,3 @@ abstract class TextFileUploadTransformationsPlugin extends IOTransformationsPlug
         return "Text file upload";
     }
 }
-?>
