@@ -6,27 +6,29 @@
  * Note: please do not fold this script into a general script
  * that would read any file using a GET parameter, it would open a hole
  *
- * @version $Id$
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
- * Load paths.
+ * Gets core libraries and defines some variables
  */
-require('./libraries/vendor_config.php');
+require 'libraries/common.inc.php';
 
 /**
  *
  */
-header('Content-type: text/plain; charset=iso-8859-1');
+header('Content-type: text/plain; charset=utf-8');
 
 $filename = LICENSE_FILE;
 
 // Check if the file is available, some distributions remove these.
-if (is_readable($filename)) {
+if (@is_readable($filename)) {
     readfile($filename);
 } else {
-    echo "The $filename file is not available on this system, please visit www.phpmyadmin.net for more information.";
+    printf(
+        __(
+            'The %s file is not available on this system, please visit ' .
+            'www.phpmyadmin.net for more information.'
+        ), $filename
+    );
 }
-
-?>
