@@ -22,6 +22,7 @@ require './libraries/config/setup.forms.php';
 $mode = isset($_GET['mode']) ? $_GET['mode'] : null;
 $id = PMA_isValid($_GET['id'], 'numeric') ? $_GET['id'] : null;
 
+/** @var ConfigFile $cf */
 $cf = $GLOBALS['ConfigFile'];
 $server_exists = !empty($id) && $cf->get("Servers/$id") !== null;
 
@@ -31,7 +32,7 @@ if ($mode == 'edit' && $server_exists) {
         . ' <small>(' . htmlspecialchars($cf->getServerDSN($id)) . ')</small>';
 } elseif ($mode == 'remove' && $server_exists) {
     $cf->removeServer($id);
-    header('Location: index.php');
+    header('Location: index.php' . PMA_URL_getCommon());
     exit;
 } elseif ($mode == 'revert' && $server_exists) {
     // handled by process_formset()
@@ -47,4 +48,3 @@ foreach ($forms['Servers'] as $form_name => $form) {
     $form_display->registerForm($form_name, $form, $id);
 }
 PMA_Process_formset($form_display);
-?>
