@@ -18,6 +18,14 @@ $pma_table = new PMA_Table($GLOBALS['table'], $GLOBALS['db']);
  */
 require_once 'libraries/operations.lib.php';
 
+/**
+ * Load JavaScript files
+ */
+$response = PMA_Response::getInstance();
+$header   = $response->getHeader();
+$scripts  = $header->getScripts();
+$scripts->addFile('tbl_operations.js');
+
 /**
  * Runs common work
  */
@@ -26,7 +34,7 @@ $url_query .= '&amp;goto=view_operations.php&amp;back=view_operations.php';
 $url_params['goto'] = $url_params['back'] = 'view_operations.php';
 
 /**
- * Gets tables informations
+ * Gets tables information
  */
 
 require './libraries/tbl_info.inc.php';
@@ -71,7 +79,7 @@ if (isset($result)) {
         unset($warning_messages);
     }
     echo PMA_Util::getMessage(
-        $_message, $sql_query, $_type, $is_view = true
+        $_message, $sql_query, $_type
     );
     unset($_message, $_type);
 }
@@ -136,4 +144,3 @@ echo PMA_getDeleteDataOrTableLink(
 echo '</ul>';
 echo '</fieldset>';
 echo '</div>';
-?>
